#!/bin/bash
# Eric · 凉城
# phpMyAdmin 一键卸载脚本 241209

# 确保脚本以 root 用户运行
if [ "$(id -u)" -ne 0 ]; then
  echo "此脚本需要以 root 用户运行。"
  exit 1
fi

# 设置 phpMyAdmin 目录和 Nginx 配置文件路径
PHPMYADMIN_DIR="/www/phpMyAdmin"
NGINX_CONF="/etc/nginx/nginx.conf"

# 检查 phpMyAdmin 是否安装
if [ ! -d "$PHPMYADMIN_DIR" ]; then
  echo "phpMyAdmin 没有安装在 ${PHPMYADMIN_DIR}。"
  exit 1
fi

# 删除 phpMyAdmin 文件
echo "删除 phpMyAdmin 文件和目录..."
rm -rf $PHPMYADMIN_DIR

# 检查 Nginx 配置文件是否包含 phpMyAdmin 配置
echo "删除 Nginx 配置文件..."
rm /usr/local/nginx/conf/sites-enabled/phpmyadmin
rm /usr/local/nginx/conf/sites-available/phpmyadmin

# 检查是否删除了 phpMyAdmin 配置文件
if grep -q "phpMyAdmin" $NGINX_CONF; then
  echo "警告: phpMyAdmin 配置删除失败，可能配置文件中仍有残留。"
else
  echo "phpMyAdmin 配置已成功从 Nginx 配置文件中删除。"
fi

# 删除 MySQL 配置中的 phpMyAdmin 相关设置（如果有的话）
echo "删除 MySQL 配置中的 phpMyAdmin 设置（如果有的话）..."
if [ -f "$PHPMYADMIN_DIR/config.inc.php" ]; then
  sed -i '/phpMyAdmin/d' /etc/mysql/my.cnf
  sed -i '/phpMyAdmin/d' /etc/mysql/mysql.conf.d/mysqld.cnf
fi

# 删除临时目录
echo "删除临时目录..."
if [ -d "$PHPMYADMIN_DIR/tmp" ]; then
  rm -rf $PHPMYADMIN_DIR/tmp
  echo "临时目录已删除。"
else
  echo "临时目录不存在，无需删除。"
fi

# 重新加载 Nginx 配置
echo "重新加载 Nginx 配置..."
service nginx restart

# 如果 PHP-FPM 版本是 7.x 或 8.x，可以选择性地重启 PHP-FPM
# 这里会自动检测 PHP 版本，并重启对应的 PHP-FPM 服务
echo "重启 PHP-FPM 服务..."
PHP_FPM_VERSION=$(php -v | head -n 1 | awk '{print $2}' | cut -d '.' -f1,2)
service php${PHP_FPM_VERSION}-fpm restart

echo "phpMyAdmin 卸载完成！"
